# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2017-01-05 19:45
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('qa', '0011_question_slug'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='question',
            name='views',
        ),
    ]
